@@ -1,3 +1,4 @@
+import unittest
 import logging
 import pycurl
 import socket
@@ -5,12 +6,13 @@ import socket
 from twisted.internet.defer import succeed, fail
 
 from landscape.broker.registration import (
-    InvalidCredentialsError, RegistrationHandler)
+    InvalidCredentialsError, RegistrationHandler, is_cloud_managed, EC2_HOST,
+    EC2_API)
 
 from landscape.broker.deployment import BrokerConfiguration
 from landscape.tests.helpers import LandscapeTest, ExchangeHelper
 from landscape.lib.bpickle import dumps
-from landscape.lib.fetch import HTTPCodeError
+from landscape.lib.fetch import HTTPCodeError, FetchError
 
 
 class RegistrationTest(LandscapeTest):
@@ -23,9 +25,9 @@ class RegistrationTest(LandscapeTest):
         self.identity = self.broker_service.identity
         self.handler = self.broker_service.registration
         logging.getLogger().setLevel(logging.INFO)
-        self.hostname = "ooga"
-        self.addCleanup(setattr, socket, "gethostname", socket.gethostname)
-        socket.gethostname = lambda: self.hostname
+        self.hostname = "ooga.local"
+        self.addCleanup(setattr, socket, "getfqdn", socket.getfqdn)
+        socket.getfqdn = lambda: self.hostname
 
     def check_persist_property(self, attr, persist_name):
         value = "VALUE"
@@ -141,7 +143,7 @@ class RegistrationTest(LandscapeTest):
                               "computer_title": "Computer Title",
                               "account_name": "account_name",
                               "registration_password": None,
-                              "hostname": "ooga"}
+                              "hostname": "ooga.local"}
                             ])
         self.assertEquals(self.logfile.getvalue().strip(),
                           "INFO: Queueing message to register with account "
@@ -159,7 +161,7 @@ class RegistrationTest(LandscapeTest):
                               "computer_title": "Computer Title",
                               "account_name": "account_name",
                               "registration_password": "SEKRET",
-                              "hostname": "ooga"}
+                              "hostname": "ooga.local"}
                             ])
         self.assertEquals(self.logfile.getvalue().strip(),
                           "INFO: Queueing message to register with account "
@@ -341,7 +343,7 @@ class RegistrationTest(LandscapeTest):
                               "computer_title": "Computer Title",
                               "account_name": "account_name",
                               "registration_password": "SEKRET",
-                              "hostname": socket.gethostname()}
+                              "hostname": socket.getfqdn()}
                              ])
 
     def get_registration_handler_for_cloud(
@@ -406,7 +408,7 @@ class RegistrationTest(LandscapeTest):
         """
         message = dict(type="register-cloud-vm",
                        otp="otp1",
-                       hostname="ooga",
+                       hostname="ooga.local",
                        local_hostname="ooga.local",
                        public_hostname="ooga.amazon.com",
                        instance_key=u"key1",
@@ -641,7 +643,7 @@ class RegistrationTest(LandscapeTest):
                               "computer_title": u"whatever",
                               "account_name": u"onward",
                               "registration_password": u"password",
-                              "hostname": socket.gethostname()}])
+                              "hostname": socket.getfqdn()}])
 
     def test_should_register_in_cloud(self):
         """
@@ -729,3 +731,151 @@ class RegistrationTest(LandscapeTest):
         config.computer_title = None
         self.broker_service.identity.secure_id = None
         self.assertFalse(handler.should_register())
+
+
+class IsCloudManagedTests(LandscapeTest):
+
+    def setUp(self):
+        super(IsCloudManagedTests, self).setUp()
+        self.urls = []
+        self.responses = []
+
+    def fake_fetch(self, url, connect_timeout=None):
+        self.urls.append((url, connect_timeout))
+        return self.responses.pop(0)
+
+    def mock_socket(self):
+        """
+        Mock out socket usage by is_cloud_managed to wait for the network.
+        """
+        # Mock the socket.connect call that it also does
+        socket_class = self.mocker.replace("socket.socket", passthrough=False)
+        socket = socket_class()
+        socket.connect((EC2_HOST, 80))
+        socket.close()
+        
+
+    def test_is_managed(self):
+        """
+        L{is_cloud_managed} returns True if the EC2 user-data contains Landscape
+        instance information.  It fetches the EC2 data with low timeouts.
+        """
+        user_data = {"otps": ["otp1"], "exchange-url": "http://exchange",
+                     "ping-url": "http://ping"}
+        self.responses = [dumps(user_data), "0"]
+
+        self.mock_socket()
+        self.mocker.replay()
+
+        self.assertTrue(is_cloud_managed(self.fake_fetch))
+        self.assertEquals(
+            self.urls,
+            [(EC2_API + "/user-data", 5),
+             (EC2_API + "/meta-data/ami-launch-index", 5)])
+
+    def test_is_managed_index(self):
+        user_data = {"otps": ["otp1", "otp2"],
+                     "exchange-url": "http://exchange",
+                     "ping-url": "http://ping"}
+        self.responses = [dumps(user_data), "1"]
+        self.mock_socket()
+        self.mocker.replay()
+        self.assertTrue(is_cloud_managed(self.fake_fetch))
+
+    def test_is_managed_wrong_index(self):
+        user_data = {"otps": ["otp1"], "exchange-url": "http://exchange",
+                     "ping-url": "http://ping"}
+        self.responses = [dumps(user_data), "1"]
+        self.mock_socket()
+        self.mocker.replay()
+        self.assertFalse(is_cloud_managed(self.fake_fetch))
+
+    def test_is_managed_exchange_url(self):
+        user_data = {"otps": ["otp1"], "ping-url": "http://ping"}
+        self.responses = [dumps(user_data), "0"]
+        self.mock_socket()
+        self.mocker.replay()
+        self.assertFalse(is_cloud_managed(self.fake_fetch))
+
+    def test_is_managed_ping_url(self):
+        user_data = {"otps": ["otp1"], "exchange-url": "http://exchange"}
+        self.responses = [dumps(user_data), "0"]
+        self.mock_socket()
+        self.mocker.replay()
+        self.assertFalse(is_cloud_managed(self.fake_fetch))
+
+    def test_is_managed_bpickle(self):
+        self.responses = ["some other user data", "0"]
+        self.mock_socket()
+        self.mocker.replay()
+        self.assertFalse(is_cloud_managed(self.fake_fetch))
+
+    def test_is_managed_no_data(self):
+        self.responses = ["", "0"]
+        self.mock_socket()
+        self.mocker.replay()
+        self.assertFalse(is_cloud_managed(self.fake_fetch))
+
+    def test_is_managed_fetch_not_found(self):
+        def fake_fetch(url, connect_timeout=None):
+            raise HTTPCodeError(404, "ohnoes")
+        self.mock_socket()
+        self.mocker.replay()
+        self.assertFalse(is_cloud_managed(fake_fetch))
+
+    def test_is_managed_fetch_error(self):
+        def fake_fetch(url, connect_timeout=None):
+            raise FetchError(7, "couldn't connect to host")
+        self.mock_socket()
+        self.mocker.replay()
+        self.assertFalse(is_cloud_managed(fake_fetch))
+
+    def test_waits_for_network(self):
+        """
+        is_cloud_managed will wait until the network before trying to fetch
+        the EC2 user data.
+        """
+        user_data = {"otps": ["otp1"], "exchange-url": "http://exchange",
+                     "ping-url": "http://ping"}
+        self.responses = [dumps(user_data), "0"]
+
+        self.mocker.order()
+        time_sleep = self.mocker.replace("time.sleep", passthrough=False)
+        socket_class = self.mocker.replace("socket.socket", passthrough=False)
+        socket_obj = socket_class()
+        socket_obj.connect((EC2_HOST, 80))
+        self.mocker.throw(socket.error("woops"))
+        time_sleep(1)
+        socket_obj = socket_class()
+        socket_obj.connect((EC2_HOST, 80))
+        self.mocker.result(None)
+        socket_obj.close()
+        self.mocker.replay()
+        self.assertTrue(is_cloud_managed(self.fake_fetch))
+
+    def test_waiting_times_out(self):
+        """
+        We'll only wait five minutes for the network to come up.
+        """
+        def fake_fetch(url, connect_timeout=None):
+            raise FetchError(7, "couldn't connect to host")
+
+        self.mocker.order()
+        time_sleep = self.mocker.replace("time.sleep", passthrough=False)
+        time_time = self.mocker.replace("time.time", passthrough=False)
+        time_time()
+        self.mocker.result(100)
+        socket_class = self.mocker.replace("socket.socket", passthrough=False)
+        socket_obj = socket_class()
+        socket_obj.connect((EC2_HOST, 80))
+        self.mocker.throw(socket.error("woops"))
+        time_sleep(1)
+        time_time()
+        self.mocker.result(401)
+        self.mocker.replay()
+        # Mocking time.time is dangerous, because the test harness calls it. So
+        # we explicitly reset mocker before returning from the test.
+        try:
+            self.assertFalse(is_cloud_managed(fake_fetch))
+        finally:
+            self.mocker.reset()
