@@ -7,8 +7,8 @@ import subprocess
 from twisted.internet.defer import fail
 
 from landscape.monitor.activeprocessinfo import ActiveProcessInfo
-from landscape.tests.helpers import (LandscapeTest, MakePathHelper,
-                                     MonitorHelper, ProcessDataBuilder)
+from landscape.tests.helpers import (LandscapeTest, MonitorHelper,
+                                     ProcessDataBuilder)
 from landscape.tests.mocker import ANY
 from landscape import API
 
@@ -16,7 +16,7 @@ from landscape import API
 class ActiveProcessInfoTest(LandscapeTest):
     """Active process info plugin tests."""
 
-    helpers = [MonitorHelper, MakePathHelper]
+    helpers = [MonitorHelper]
 
     def setUp(self):
         """Initialize helpers and sample data builder."""
@@ -495,11 +495,11 @@ class ActiveProcessInfoTest(LandscapeTest):
 
 class PluginManagerIntegrationTest(LandscapeTest):
 
-    helpers = [MonitorHelper, MakePathHelper]
+    helpers = [MonitorHelper]
 
     def setUp(self):
         LandscapeTest.setUp(self)
-        self.sample_dir = self.make_dir()
+        self.sample_dir = self.makeDir()
         self.builder = ProcessDataBuilder(self.sample_dir)
         self.mstore.set_accepted_types(["active-process-info",
                                         "operation-result"])
