@@ -2,29 +2,40 @@ import glob
 import sys
 import os
 import logging
+import unittest
 
 from twisted.internet.defer import Deferred
 from twisted.internet import reactor
 
 from landscape.lib.fetch import fetch_async, FetchError
-from landscape.lib.command import CommandError
-
 from landscape.package.store import PackageStore, UnknownHashIDRequest
 from landscape.package.reporter import (
-    PackageReporter, HASH_ID_REQUEST_TIMEOUT, main, find_reporter_command)
+    PackageReporter, HASH_ID_REQUEST_TIMEOUT, main, find_reporter_command,
+    PackageReporterConfiguration)
 from landscape.package import reporter
 from landscape.package.facade import SmartFacade
-
-from landscape.deployment import Configuration
 from landscape.broker.remote import RemoteBroker
-
 from landscape.package.tests.helpers import (
     SmartFacadeHelper, HASH1, HASH2, HASH3)
-
 from landscape.tests.helpers import (
     LandscapeIsolatedTest, RemoteBrokerHelper)
 from landscape.tests.mocker import ANY
 
+SAMPLE_LSB_RELEASE = "DISTRIB_CODENAME=codename\n"
+
+
+class PackageReporterConfigurationTest(unittest.TestCase):
+
+    def test_force_smart_update_option(self):
+        """
+        The L{PackageReporterConfiguration} supports a '--force-smart-update'
+        command line option.
+        """
+        config = PackageReporterConfiguration()
+        self.assertFalse(config.force_smart_update)
+        config.load(["--force-smart-update"])
+        self.assertTrue(config.force_smart_update)
+
 
 class PackageReporterTest(LandscapeIsolatedTest):
 
@@ -34,11 +45,13 @@ class PackageReporterTest(LandscapeIsolatedTest):
         super(PackageReporterTest, self).setUp()
 
         self.store = PackageStore(self.makeFile())
-        self.config = Configuration()
-        self.reporter = PackageReporter(self.store, self.facade, self.remote, self.config)
+        self.config = PackageReporterConfiguration()
+        self.reporter = PackageReporter(self.store, self.facade, self.remote,
+                                        self.config)
 
     def set_pkg2_upgrades_pkg1(self):
         previous = self.Facade.channels_reloaded
+
         def callback(self):
             from smart.backends.deb.base import DebUpgrades
             previous(self)
@@ -49,15 +62,16 @@ class PackageReporterTest(LandscapeIsolatedTest):
 
     def set_pkg1_installed(self):
         previous = self.Facade.channels_reloaded
+
         def callback(self):
             previous(self)
             self.get_packages_by_name("name1")[0].installed = True
         self.Facade.channels_reloaded = callback
 
     def test_set_package_ids_with_all_known(self):
-        request1 = self.store.add_hash_id_request(["hash1", "hash2"])
+        self.store.add_hash_id_request(["hash1", "hash2"])
         request2 = self.store.add_hash_id_request(["hash3", "hash4"])
-        request3 = self.store.add_hash_id_request(["hash5", "hash6"])
+        self.store.add_hash_id_request(["hash5", "hash6"])
 
         self.store.add_task("reporter",
                             {"type": "package-ids", "ids": [123, 456],
@@ -164,7 +178,6 @@ class PackageReporterTest(LandscapeIsolatedTest):
                                 "request-id": request2.id,
                   "type": "add-packages"}])
 
-
         class FakePackage(object):
             type = 65537
             name = u"name1"
@@ -187,7 +200,9 @@ class PackageReporterTest(LandscapeIsolatedTest):
         message_store = self.broker_service.message_store
         message_store.set_accepted_types(["add-packages"])
 
-        class Boom(Exception): pass
+        class Boom(Exception):
+            pass
+
         deferred = Deferred()
         deferred.errback(Boom())
 
@@ -236,9 +251,7 @@ class PackageReporterTest(LandscapeIsolatedTest):
         # Fake uuid, codename and arch
         message_store = self.broker_service.message_store
         message_store.set_server_uuid("uuid")
-        command_mock = self.mocker.replace("landscape.lib.command.run_command")
-        command_mock("lsb_release -cs")
-        self.mocker.result("codename")
+        self.reporter.lsb_release_filename = self.makeFile(SAMPLE_LSB_RELEASE)
         self.facade.set_arch("arch")
 
         # Let's say fetch_async is successful
@@ -282,9 +295,7 @@ class PackageReporterTest(LandscapeIsolatedTest):
         # Fake uuid, codename and arch
         message_store = self.broker_service.message_store
         message_store.set_server_uuid("uuid")
-        command_mock = self.mocker.replace("landscape.lib.command.run_command")
-        command_mock("lsb_release -cs")
-        self.mocker.result("codename")
+        self.reporter.lsb_release_filename = self.makeFile(SAMPLE_LSB_RELEASE)
         self.facade.set_arch("arch")
 
         # Intercept any call to fetch_async
@@ -331,15 +342,13 @@ class PackageReporterTest(LandscapeIsolatedTest):
         message_store.set_server_uuid("uuid")
 
         # Undetermined codename
-        command_mock = self.mocker.replace("landscape.lib.command.run_command")
-        command_mock("lsb_release -cs")
-        command_error = CommandError("lsb_release -cs", 1, "error")
-        self.mocker.throw(command_error)
+        self.reporter.lsb_release_filename = self.makeFile("Foo=bar")
 
         # The failure should be properly logged
         logging_mock = self.mocker.replace("logging.warning")
-        logging_mock("Couldn't determine which hash=>id database to use: %s" %
-                     str(command_error))
+        logging_mock("Couldn't determine which hash=>id database to use: "
+                     "missing code-name key in %s" %
+                     self.reporter.lsb_release_filename)
         self.mocker.result(None)
 
         # Go!
@@ -353,9 +362,7 @@ class PackageReporterTest(LandscapeIsolatedTest):
         # Fake uuid and codename
         message_store = self.broker_service.message_store
         message_store.set_server_uuid("uuid")
-        command_mock = self.mocker.replace("landscape.lib.command.run_command")
-        command_mock("lsb_release -cs")
-        self.mocker.result("codename")
+        self.reporter.lsb_release_filename = self.makeFile(SAMPLE_LSB_RELEASE)
 
         # Undetermined arch
         self.facade.set_arch(None)
@@ -385,9 +392,7 @@ class PackageReporterTest(LandscapeIsolatedTest):
         # Fake uuid, codename and arch
         message_store = self.broker_service.message_store
         message_store.set_server_uuid("uuid")
-        command_mock = self.mocker.replace("landscape.lib.command.run_command")
-        command_mock("lsb_release -cs")
-        self.mocker.result("codename")
+        self.reporter.lsb_release_filename = self.makeFile(SAMPLE_LSB_RELEASE)
         self.facade.set_arch("arch")
 
         # Check fetch_async is called with the default url
@@ -419,9 +424,7 @@ class PackageReporterTest(LandscapeIsolatedTest):
         # Fake uuid, codename and arch
         message_store = self.broker_service.message_store
         message_store.set_server_uuid("uuid")
-        command_mock = self.mocker.replace("landscape.lib.command.run_command")
-        command_mock("lsb_release -cs")
-        self.mocker.result("codename")
+        self.reporter.lsb_release_filename = self.makeFile(SAMPLE_LSB_RELEASE)
         self.facade.set_arch("arch")
 
         # Let's say fetch_async fails
@@ -459,9 +462,7 @@ class PackageReporterTest(LandscapeIsolatedTest):
         # Fake uuid, codename and arch
         message_store = self.broker_service.message_store
         message_store.set_server_uuid("uuid")
-        command_mock = self.mocker.replace("landscape.lib.command.run_command")
-        command_mock("lsb_release -cs")
-        self.mocker.result("codename")
+        self.reporter.lsb_release_filename = self.makeFile(SAMPLE_LSB_RELEASE)
         self.facade.set_arch("arch")
 
         # The failure should be properly logged
@@ -495,9 +496,7 @@ class PackageReporterTest(LandscapeIsolatedTest):
         # Fake uuid, codename and arch
         message_store = self.broker_service.message_store
         message_store.set_server_uuid("uuid")
-        command_mock = self.mocker.replace("landscape.lib.command.run_command")
-        command_mock("lsb_release -cs")
-        self.mocker.result("codename")
+        self.reporter.lsb_release_filename = self.makeFile(SAMPLE_LSB_RELEASE)
         self.facade.set_arch("arch")
 
         # Check fetch_async is called with the default url
@@ -531,10 +530,13 @@ class PackageReporterTest(LandscapeIsolatedTest):
         deferred = Deferred()
 
         def do_test():
+
             def raiseme(x):
                 raise Exception
+
             logging.warning = raiseme
             result = self.reporter.run_smart_update()
+
             def callback((out, err, code)):
                 interval = self.reporter.smart_update_interval
                 self.assertEquals(out, "--after %d" % interval)
@@ -546,6 +548,30 @@ class PackageReporterTest(LandscapeIsolatedTest):
         reactor.callWhenRunning(do_test)
         return deferred
 
+    def test_run_smart_update_with_force_smart_update(self):
+        """
+        L{PackageReporter.run_smart_update} forces a smart-update run if
+        the '--force-smart-update' command line option was passed.
+
+        """
+        self.config.load(["--force-smart-update"])
+        self.reporter.smart_update_filename = self.makeFile(
+            "#!/bin/sh\necho -n $@")
+        os.chmod(self.reporter.smart_update_filename, 0755)
+
+        deferred = Deferred()
+
+        def do_test():
+            result = self.reporter.run_smart_update()
+
+            def callback((out, err, code)):
+                self.assertEquals(out, "")
+            result.addCallback(callback)
+            result.chainDeferred(deferred)
+
+        reactor.callWhenRunning(do_test)
+        return deferred
+
     def test_run_smart_update_warns_about_failures(self):
         """
         The L{PackageReporter.run_smart_update} method should log a warning
@@ -562,8 +588,8 @@ class PackageReporterTest(LandscapeIsolatedTest):
 
         def do_test():
             result = self.reporter.run_smart_update()
+
             def callback((out, err, code)):
-                interval = self.reporter.smart_update_interval
                 self.assertEquals(out, "output")
                 self.assertEquals(err, "error")
                 self.assertEquals(code, 2)
@@ -586,10 +612,11 @@ class PackageReporterTest(LandscapeIsolatedTest):
                      " (error  )" % self.reporter.smart_update_filename)
         self.mocker.replay()
         deferred = Deferred()
+
         def do_test():
             result = self.reporter.run_smart_update()
+
             def callback((out, err, code)):
-                interval = self.reporter.smart_update_interval
                 self.assertEquals(out, "")
                 self.assertEquals(err, "error  ")
                 self.assertEquals(code, 1)
@@ -609,13 +636,15 @@ class PackageReporterTest(LandscapeIsolatedTest):
             "#!/bin/sh\necho\nexit 1")
         os.chmod(self.reporter.smart_update_filename, 0755)
         deferred = Deferred()
+
         def do_test():
+
             def raiseme(x):
                 raise Exception
             logging.warning = raiseme
             result = self.reporter.run_smart_update()
+
             def callback((out, err, code)):
-                interval = self.reporter.smart_update_interval
                 self.assertEquals(out, "\n")
                 self.assertEquals(err, "")
                 self.assertEquals(code, 1)
@@ -780,7 +809,9 @@ class PackageReporterTest(LandscapeIsolatedTest):
         message_store = self.broker_service.message_store
         message_store.set_accepted_types(["unknown-package-hashes"])
 
-        class Boom(Exception): pass
+        class Boom(Exception):
+            pass
+
         deferred = Deferred()
         deferred.errback(Boom())
 
@@ -860,7 +891,7 @@ class PackageReporterTest(LandscapeIsolatedTest):
                                 [{"type": "packages",
                                   "not-available": [(1, 3)]}])
 
-            self.assertEquals(sorted(self.store.get_available()), [])
+            self.assertEquals(self.store.get_available(), [])
 
         result = self.reporter.detect_changes()
         return result.addCallback(got_result)
@@ -878,7 +909,7 @@ class PackageReporterTest(LandscapeIsolatedTest):
             self.assertMessages(message_store.get_pending_messages(),
                                 [{"type": "packages", "installed": [1]}])
 
-            self.assertEquals(sorted(self.store.get_installed()), [1])
+            self.assertEquals(self.store.get_installed(), [1])
 
         result = self.reporter.detect_changes()
         return result.addCallback(got_result)
@@ -911,7 +942,7 @@ class PackageReporterTest(LandscapeIsolatedTest):
             self.assertMessages(message_store.get_pending_messages(),
                                 [{"type": "packages", "not-installed": [1]}])
 
-            self.assertEquals(sorted(self.store.get_installed()), [])
+            self.assertEquals(self.store.get_installed(), [])
 
         result = self.reporter.detect_changes()
         return result.addCallback(got_result)
@@ -947,7 +978,7 @@ class PackageReporterTest(LandscapeIsolatedTest):
                                 [{"type": "packages",
                                   "available-upgrades": [2]}])
 
-            self.assertEquals(sorted(self.store.get_available_upgrades()), [2])
+            self.assertEquals(self.store.get_available_upgrades(), [2])
 
         result = self.reporter.detect_changes()
         return result.addCallback(got_result)
@@ -965,17 +996,214 @@ class PackageReporterTest(LandscapeIsolatedTest):
                                 [{"type": "packages",
                                   "not-available-upgrades": [2]}])
 
-            self.assertEquals(sorted(self.store.get_available_upgrades()), [])
+            self.assertEquals(self.store.get_available_upgrades(), [])
 
         result = self.reporter.detect_changes()
         return result.addCallback(got_result)
 
+    def test_detect_changes_with_locked(self):
+        """
+        If Smart indicates locked packages we didn't know about, report
+        them to the server.
+        """
+        message_store = self.broker_service.message_store
+        message_store.set_accepted_types(["packages"])
+
+        self.facade.set_package_lock("name1")
+        self.facade.set_package_lock("name2", ">=", "version2")
+
+        self.store.set_hash_ids({HASH1: 1, HASH2: 2})
+        self.store.add_available([1, 2])
+
+        def got_result(result):
+            self.assertMessages(message_store.get_pending_messages(),
+                                [{"type": "packages", "locked": [1, 2]}])
+            self.assertEquals(sorted(self.store.get_locked()), [1, 2])
+
+        result = self.reporter.detect_changes()
+        return result.addCallback(got_result)
+
+    def test_detect_changes_with_locked_and_ranges(self):
+        """
+        Ranges are used when reporting changes to 3 or more locked packages
+        having consecutive ids.
+        """
+        message_store = self.broker_service.message_store
+        message_store.set_accepted_types(["packages"])
+
+        self.facade.set_package_lock("name1")
+        self.facade.set_package_lock("name2", ">=", "version2")
+        self.facade.set_package_lock("name3", "<", "version4")
+
+        self.store.set_hash_ids({HASH1: 1, HASH2: 2, HASH3: 3})
+        self.store.add_available([1, 2, 3])
+
+        def got_result(result):
+            self.assertMessages(message_store.get_pending_messages(),
+                                [{"type": "packages", "locked": [(1, 3)]}])
+            self.assertEquals(sorted(self.store.get_locked()), [1, 2, 3])
+
+        result = self.reporter.detect_changes()
+        return result.addCallback(got_result)
+
+    def test_detect_changes_with_locked_with_unknown_hash(self):
+        """
+        Locked packages whose hashes are unknown don't get reported.
+        """
+        self.facade.set_package_lock("name1")
+
+        def got_result(result):
+            self.assertEquals(self.store.get_locked(), [])
+
+        result = self.reporter.detect_changes()
+        return result.addCallback(got_result)
+
+    def test_detect_changes_with_locked_and_previously_known(self):
+        """
+        We don't report locked packages we already know about.
+        """
+        message_store = self.broker_service.message_store
+        message_store.set_accepted_types(["packages"])
+
+        self.facade.set_package_lock("name1")
+        self.facade.set_package_lock("name2", ">=", "version2")
+
+        self.store.set_hash_ids({HASH1: 1, HASH2: 2})
+        self.store.add_available([1, 2])
+        self.store.add_locked([1])
+
+        def got_result(result):
+            self.assertMessages(message_store.get_pending_messages(),
+                                [{"type": "packages", "locked": [2]}])
+
+            self.assertEquals(sorted(self.store.get_locked()), [1, 2])
+
+        result = self.reporter.detect_changes()
+        return result.addCallback(got_result)
+
+    def test_detect_changes_with_not_locked(self):
+        """
+        We report when a package was previously locked and isn't anymore.
+        """
+        message_store = self.broker_service.message_store
+        message_store.set_accepted_types(["packages"])
+
+        self.store.set_hash_ids({HASH1: 1})
+        self.store.add_available([1])
+        self.store.add_locked([1])
+
+        def got_result(result):
+            self.assertMessages(message_store.get_pending_messages(),
+                                [{"type": "packages", "not-locked": [1]}])
+            self.assertEquals(self.store.get_locked(), [])
+
+        result = self.reporter.detect_changes()
+        return result.addCallback(got_result)
+
+    def test_detect_changes_with_not_locked_and_ranges(self):
+        """
+        Ranges are used when reporting changes to 3 or more not locked packages
+        having consecutive ids.
+        """
+        message_store = self.broker_service.message_store
+        message_store.set_accepted_types(["packages"])
+
+        self.store.add_locked([1, 2, 3])
+
+        self.store.set_hash_ids({HASH1: 1, HASH2: 2, HASH3: 3})
+        self.store.add_available([1, 2, 3])
+
+        def got_result(result):
+            self.assertMessages(message_store.get_pending_messages(),
+                                [{"type": "packages", "not-locked": [(1, 3)]}])
+            self.assertEquals(sorted(self.store.get_locked()), [])
+
+        result = self.reporter.detect_changes()
+        return result.addCallback(got_result)
+
+    def test_detect_package_locks_changes_with_create_locks(self):
+        """
+        If Smart indicates package locks we didn't know about, report
+        them to the server.
+        """
+        message_store = self.broker_service.message_store
+        message_store.set_accepted_types(["package-locks"])
+
+        self.facade.set_package_lock("name")
+
+        logging_mock = self.mocker.replace("logging.info")
+        logging_mock("Queuing message with changes in known package locks:"
+                     " 1 created, 0 deleted.")
+        self.mocker.replay()
+
+        def got_result(result):
+            self.assertMessages(message_store.get_pending_messages(),
+                                [{"type": "package-locks",
+                                  "created": [("name", "", "")]}])
+            self.assertEquals(self.store.get_package_locks(),
+                              [("name", "", "")])
+
+        result = self.reporter.detect_package_locks_changes()
+        return result.addCallback(got_result)
+
+    def test_detect_package_locks_changes_with_already_known_locks(self):
+        """
+        We don't report changes about locks we already know about.
+        """
+        message_store = self.broker_service.message_store
+        message_store.set_accepted_types(["package-locks"])
+
+        self.facade.set_package_lock("name1")
+        self.facade.set_package_lock("name2", "<", "1.2")
+
+        self.store.add_package_locks([("name1", "", "")])
+
+        logging_mock = self.mocker.replace("logging.info")
+        logging_mock("Queuing message with changes in known package locks:"
+                     " 1 created, 0 deleted.")
+        self.mocker.replay()
+
+        def got_result(result):
+            self.assertMessages(message_store.get_pending_messages(),
+                                [{"type": "package-locks",
+                                  "created": [("name2", "<", "1.2")]}])
+            self.assertEquals(sorted(self.store.get_package_locks()),
+                              [("name1", "", ""),
+                               ("name2", "<", "1.2")])
+
+        result = self.reporter.detect_package_locks_changes()
+        return result.addCallback(got_result)
+
+    def test_detect_package_locks_changes_with_deleted_locks(self):
+        """
+        If Smart indicates newly unset package locks, report them to the
+        server.
+        """
+        message_store = self.broker_service.message_store
+        message_store.set_accepted_types(["package-locks"])
+
+        self.store.add_package_locks([("name1", "", "")])
+
+        logging_mock = self.mocker.replace("logging.info")
+        logging_mock("Queuing message with changes in known package locks:"
+                     " 0 created, 1 deleted.")
+        self.mocker.replay()
+
+        def got_result(result):
+            self.assertMessages(message_store.get_pending_messages(),
+                                [{"type": "package-locks",
+                                  "deleted": [("name1", "", "")]}])
+            self.assertEquals(self.store.get_package_locks(), [])
+
+        result = self.reporter.detect_package_locks_changes()
+        return result.addCallback(got_result)
+
     def test_run(self):
         reporter_mock = self.mocker.patch(self.reporter)
 
         self.mocker.order()
 
-        results = [Deferred() for i in range(7)]
+        results = [Deferred() for i in range(8)]
 
         reporter_mock.run_smart_update()
         self.mocker.result(results[0])
@@ -998,6 +1226,9 @@ class PackageReporterTest(LandscapeIsolatedTest):
         reporter_mock.detect_changes()
         self.mocker.result(results[6])
 
+        reporter_mock.detect_package_locks_changes()
+        self.mocker.result(results[7])
+
         self.mocker.replay()
 
         self.reporter.run()
@@ -1011,8 +1242,6 @@ class PackageReporterTest(LandscapeIsolatedTest):
             deferred.callback(None)
 
     def test_main(self):
-        data_path = self.makeDir()
-
         run_task_handler = self.mocker.replace("landscape.package.taskhandler"
                                                ".run_task_handler",
                                                passthrough=False)
