@@ -4,18 +4,16 @@ from twisted.internet import reactor
 from twisted.internet.defer import Deferred, fail
 
 from landscape.lib.lock import lock_path
-from landscape.lib.command import CommandError
 
-from landscape.deployment import Configuration
-from landscape.broker.remote import RemoteBroker
-
-from landscape.package.taskhandler import PackageTaskHandler, run_task_handler
+from landscape.package.taskhandler import (
+    PackageTaskHandlerConfiguration, PackageTaskHandler, run_task_handler,
+    LazyRemoteBroker)
 from landscape.package.facade import SmartFacade
 from landscape.package.store import HashIdStore, PackageStore
 from landscape.package.tests.helpers import SmartFacadeHelper
 
 from landscape.tests.helpers import (
-    LandscapeIsolatedTest, RemoteBrokerHelper)
+    LandscapeTest, LandscapeIsolatedTest, RemoteBrokerHelper)
 from landscape.tests.mocker import ANY, ARGS, MATCH
 
 
@@ -23,6 +21,9 @@ def ISTYPE(match_type):
     return MATCH(lambda arg: type(arg) is match_type)
 
 
+SAMPLE_LSB_RELEASE = "DISTRIB_CODENAME=codename\n"
+
+
 class PackageTaskHandlerTest(LandscapeIsolatedTest):
 
     helpers = [SmartFacadeHelper, RemoteBrokerHelper]
@@ -30,10 +31,10 @@ class PackageTaskHandlerTest(LandscapeIsolatedTest):
     def setUp(self):
         super(PackageTaskHandlerTest, self).setUp()
 
-        self.config = Configuration()
+        self.config = PackageTaskHandlerConfiguration()
         self.store = PackageStore(self.makeFile())
-
-        self.handler = PackageTaskHandler(self.store, self.facade, self.remote, self.config)
+        self.handler = PackageTaskHandler(self.store, self.facade, self.remote,
+                                          self.config)
 
     def test_ensure_channels_reloaded(self):
         self.assertEquals(len(self.facade.get_packages()), 0)
@@ -60,9 +61,7 @@ class PackageTaskHandlerTest(LandscapeIsolatedTest):
         # Fake uuid, codename and arch
         message_store = self.broker_service.message_store
         message_store.set_server_uuid("uuid")
-        command_mock = self.mocker.replace("landscape.lib.command.run_command")
-        command_mock("lsb_release -cs")
-        self.mocker.result("codename")
+        self.handler.lsb_release_filename = self.makeFile(SAMPLE_LSB_RELEASE)
         self.facade.set_arch("arch")
 
         # Attach the hash=>id database to our store
@@ -83,21 +82,39 @@ class PackageTaskHandlerTest(LandscapeIsolatedTest):
         message_store.set_server_uuid("uuid")
 
         # Undetermined codename
-        command_mock = self.mocker.replace("landscape.lib.command.run_command")
-        command_mock("lsb_release -cs")
-        command_error = CommandError("lsb_release -cs", 1, "error")
-        self.mocker.throw(command_error)
+        self.handler.lsb_release_filename = self.makeFile("Foo=bar")
 
         # The failure should be properly logged
         logging_mock = self.mocker.replace("logging.warning")
-        logging_mock("Couldn't determine which hash=>id database to use: %s" %
-                     str(command_error))
+        logging_mock("Couldn't determine which hash=>id database to use: "
+                     "missing code-name key in %s" %
+                     self.handler.lsb_release_filename)
         self.mocker.result(None)
 
         # Go!
         self.mocker.replay()
         result = self.handler.use_hash_id_db()
+        return result
 
+    def test_use_hash_id_db_wit_non_existing_lsb_release(self):
+
+        # Fake uuid
+        message_store = self.broker_service.message_store
+        message_store.set_server_uuid("uuid")
+
+        # Undetermined codename
+        self.handler.lsb_release_filename = self.makeFile()
+
+        # The failure should be properly logged
+        logging_mock = self.mocker.replace("logging.warning")
+        logging_mock("Couldn't determine which hash=>id database to use: "
+                     "[Errno 2] No such file or directory: '%s'" %
+                     self.handler.lsb_release_filename)
+        self.mocker.result(None)
+
+        # Go!
+        self.mocker.replay()
+        result = self.handler.use_hash_id_db()
         return result
 
     def test_wb_determine_hash_id_db_filename_server_uuid_is_none(self):
@@ -109,11 +126,12 @@ class PackageTaskHandlerTest(LandscapeIsolatedTest):
         message_store.set_server_uuid(None)
 
         result = self.handler._determine_hash_id_db_filename()
+
         def callback(hash_id_db_filename):
             self.assertIs(hash_id_db_filename, None)
         result.addCallback(callback)
         return result
-        
+
     def test_use_hash_id_db_undetermined_server_uuid(self):
         """
         If the server-uuid can't be determined for some reason, no hash-id db
@@ -129,6 +147,7 @@ class PackageTaskHandlerTest(LandscapeIsolatedTest):
         self.mocker.replay()
 
         result = self.handler.use_hash_id_db()
+
         def callback(ignore):
             self.assertFalse(self.store.has_hash_id_db())
         result.addCallback(callback)
@@ -139,9 +158,7 @@ class PackageTaskHandlerTest(LandscapeIsolatedTest):
         # Fake uuid and codename
         message_store = self.broker_service.message_store
         message_store.set_server_uuid("uuid")
-        command_mock = self.mocker.replace("landscape.lib.command.run_command")
-        command_mock("lsb_release -cs")
-        self.mocker.result("codename")
+        self.handler.lsb_release_filename = self.makeFile(SAMPLE_LSB_RELEASE)
 
         # Undetermined arch
         self.facade.set_arch(None)
@@ -166,9 +183,7 @@ class PackageTaskHandlerTest(LandscapeIsolatedTest):
         # Fake uuid, codename and arch
         message_store = self.broker_service.message_store
         message_store.set_server_uuid("uuid")
-        command_mock = self.mocker.replace("landscape.lib.command.run_command")
-        command_mock("lsb_release -cs")
-        self.mocker.result("codename")
+        self.handler.lsb_release_filename = self.makeFile(SAMPLE_LSB_RELEASE)
         self.facade.set_arch("arch")
 
         # Let's try
@@ -194,9 +209,7 @@ class PackageTaskHandlerTest(LandscapeIsolatedTest):
         # Fake uuid, codename and arch
         message_store = self.broker_service.message_store
         message_store.set_server_uuid("uuid")
-        command_mock = self.mocker.replace("landscape.lib.command.run_command")
-        command_mock("lsb_release -cs")
-        self.mocker.result("codename")
+        self.handler.lsb_release_filename = self.makeFile(SAMPLE_LSB_RELEASE)
         self.facade.set_arch("arch")
 
         # The failure should be properly logged
@@ -235,6 +248,7 @@ class PackageTaskHandlerTest(LandscapeIsolatedTest):
         results = [Deferred() for i in range(3)]
 
         stash = []
+
         def handle_task(task):
             result = results[task.data]
             result.addCallback(lambda x: stash.append(task.data))
@@ -256,7 +270,7 @@ class PackageTaskHandlerTest(LandscapeIsolatedTest):
 
         results[0].callback(None)
         self.assertEquals(stash, [0, 1])
-        self.assertFalse(handle_tasks_result.called)
+        self.assertTrue(handle_tasks_result.called)
         self.assertEquals(self.store.get_next_task(queue_name).data, 2)
 
         results[2].callback(None)
@@ -272,7 +286,8 @@ class PackageTaskHandlerTest(LandscapeIsolatedTest):
 
         self.store.add_task(queue_name, 0)
 
-        class MyException(Exception): pass
+        class MyException(Exception):
+            pass
 
         def handle_task(task):
             result = Deferred()
@@ -305,8 +320,7 @@ class PackageTaskHandlerTest(LandscapeIsolatedTest):
         # Prepare the mock objects.
         lock_path_mock = self.mocker.replace("landscape.lib.lock.lock_path",
                                              passthrough=False)
-        install_mock = self.mocker.replace("twisted.internet."
-                                           "glib2reactor.install")
+        install_mock = self.mocker.replace("landscape.reactor.install")
         reactor_mock = self.mocker.replace("twisted.internet.reactor",
                                            passthrough=False)
         init_logging_mock = self.mocker.replace("landscape.deployment"
@@ -330,22 +344,20 @@ class PackageTaskHandlerTest(LandscapeIsolatedTest):
         # Once locking is done, it's safe to start logging without
         # corrupting the file.  We don't want any output unless it's
         # breaking badly, so the quiet option should be set.
-        init_logging_mock(ISTYPE(Configuration), "package-default")
+        init_logging_mock(ISTYPE(PackageTaskHandlerConfiguration),
+                          "package-task-handler")
 
         # Then, it must create an instance of the TaskHandler subclass
         # passed in as a parameter.  We'll keep track of the arguments
         # given and verify them later.
         handler_args = []
-        handler_mock = HandlerMock(ANY, ANY, ANY, ANY)
+        HandlerMock(ANY, ANY, ANY, ANY)
         self.mocker.passthrough() # Let the real constructor run for testing.
         self.mocker.call(lambda *args: handler_args.extend(args))
 
-        # Finally, the task handler must be run, and will return a deferred.
-        # We'll return a real deferred so that we can call it back and test
-        # whatever was hooked in as well.
-        deferred = Deferred()
-        handler_mock.run()
-        self.mocker.result(deferred)
+        to_call = []
+        reactor_mock.callWhenRunning(ANY)
+        self.mocker.call(lambda callback: to_call.append(callback))
 
         # With all of that done, the Twisted reactor must be run, so that
         # deferred tasks are correctly performed.
@@ -369,15 +381,14 @@ class PackageTaskHandlerTest(LandscapeIsolatedTest):
 
         try:
             # DO IT!
-            result = run_task_handler(HandlerMock,
-                                      ["--data-path", data_path,
-                                       "--bus", "session"])
+            run_task_handler(HandlerMock, ["--data-path", data_path,
+                                           "--bus", "session"])
 
             # reactor.stop() wasn't run yet, so it must fail right now.
             self.assertRaises(AssertionError, self.mocker.verify)
 
             # DO THE REST OF IT! :-)
-            result.callback(None)
+            to_call[0]()
 
             # Are we there yet!?
             self.mocker.verify()
@@ -390,8 +401,8 @@ class PackageTaskHandlerTest(LandscapeIsolatedTest):
         # Verify if the arguments to the reporter constructor were correct.
         self.assertEquals(type(store), PackageStore)
         self.assertEquals(type(facade), SmartFacade)
-        self.assertEquals(type(broker), RemoteBroker)
-        self.assertEquals(type(config), Configuration)
+        self.assertEquals(type(broker), LazyRemoteBroker)
+        self.assertEquals(type(config), PackageTaskHandlerConfiguration)
 
         # Let's see if the store path is where it should be.
         filename = os.path.join(data_path, "package", "database")
@@ -406,8 +417,7 @@ class PackageTaskHandlerTest(LandscapeIsolatedTest):
     def test_run_task_handler_when_already_locked(self):
         data_path = self.makeDir()
 
-        install_mock = self.mocker.replace("twisted.internet."
-                                           "glib2reactor.install")
+        install_mock = self.mocker.replace("landscape.reactor.install")
         install_mock()
 
         self.mocker.replay()
@@ -425,8 +435,7 @@ class PackageTaskHandlerTest(LandscapeIsolatedTest):
     def test_run_task_handler_when_already_locked_and_quiet_option(self):
         data_path = self.makeDir()
 
-        install_mock = self.mocker.replace("twisted.internet."
-                                           "glib2reactor.install")
+        install_mock = self.mocker.replace("landscape.reactor.install")
         install_mock()
 
         self.mocker.replay()
@@ -444,8 +453,7 @@ class PackageTaskHandlerTest(LandscapeIsolatedTest):
 
     def test_errors_in_tasks_are_printed_and_exit_program(self):
         # Ignore a bunch of crap that we don't care about
-        install_mock = self.mocker.replace("twisted.internet."
-                                           "glib2reactor.install")
+        install_mock = self.mocker.replace("landscape.reactor.install")
         install_mock()
         reactor_mock = self.mocker.proxy(reactor)
         init_logging_mock = self.mocker.replace("landscape.deployment"
@@ -481,3 +489,20 @@ class PackageTaskHandlerTest(LandscapeIsolatedTest):
             self.assertIn("MyException", self.logfile.getvalue())
 
         return done.addCallback(everything_stopped)
+
+
+class LazyRemoteBrokerTest(LandscapeTest):
+
+
+    def test_wb_is_lazy(self):
+        """
+        The L{LazyRemoteBroker} class doesn't initialize the actual remote
+        broker until one of its attributes gets actually accessed.
+        """
+        self.broker = LazyRemoteBroker("bus")
+        self.assertIdentical(self.broker._remote, None)
+        get_bus_mock = self.mocker.replace("landscape.lib.dbus_util.get_bus")
+        get_bus_mock("bus")
+        self.mocker.result("bus_object")
+        self.mocker.replay()
+        self.assertEquals(self.broker.bus, "bus_object")
