@@ -1258,6 +1258,7 @@ account_name = account
 
         config_filename = self.makeFile("")
         key_filename = config_filename + ".ssl_public_key"
+        self.addCleanup(os.remove, key_filename)
 
         print_text_mock = self.mocker.replace(print_text)
         print_text_mock("Writing SSL public key to %s..." % key_filename)
@@ -1352,8 +1353,7 @@ class RegisterFunctionTest(LandscapeIsolatedTest):
         config_mock = self.mocker.replace(service.config)
         print_text_mock = self.mocker.replace(print_text)
         reactor_mock = self.mocker.proxy("twisted.internet.reactor")
-        install_mock = self.mocker.replace("twisted.internet."
-                                           "glib2reactor.install")
+        install_mock = self.mocker.replace("landscape.reactor.install")
 
         # This must necessarily happen in the following order.
         self.mocker.order()
@@ -1410,8 +1410,7 @@ class RegisterFunctionTest(LandscapeIsolatedTest):
         config_mock = self.mocker.replace(service.config)
         print_text_mock = self.mocker.replace(print_text)
         reactor_mock = self.mocker.proxy("twisted.internet.reactor")
-        install_mock = self.mocker.replace("twisted.internet."
-                                           "glib2reactor.install")
+        install_mock = self.mocker.replace("landscape.reactor.install")
 
         # This must necessarily happen in the following order.
         self.mocker.order()
@@ -1467,8 +1466,7 @@ class RegisterFunctionTest(LandscapeIsolatedTest):
         config_mock = self.mocker.replace(service.config)
         print_text_mock = self.mocker.replace(print_text)
         reactor_mock = self.mocker.proxy("twisted.internet.reactor")
-        install_mock = self.mocker.replace("twisted.internet."
-                                           "glib2reactor.install")
+        install_mock = self.mocker.replace("landscape.reactor.install")
 
         # This must necessarily happen in the following order.
         self.mocker.order()
@@ -1526,8 +1524,7 @@ class RegisterFunctionTest(LandscapeIsolatedTest):
         config_mock = self.mocker.replace(service.config)
         print_text_mock = self.mocker.replace(print_text)
         reactor_mock = self.mocker.proxy("twisted.internet.reactor")
-        install_mock = self.mocker.replace("twisted.internet."
-                                           "glib2reactor.install")
+        install_mock = self.mocker.replace("landscape.reactor.install")
 
         # This must necessarily happen in the following order.
         self.mocker.order()
@@ -1573,8 +1570,7 @@ class RegisterFunctionTest(LandscapeIsolatedTest):
         remote_broker_factory = self.mocker.replace(
             "landscape.broker.remote.RemoteBroker", passthrough=False)
         print_text_mock = self.mocker.replace(print_text)
-        install_mock = self.mocker.replace("twisted.internet."
-                                           "glib2reactor.install")
+        install_mock = self.mocker.replace("landscape.reactor.install")
         time_mock = self.mocker.replace("time")
 
         install_mock()
@@ -1603,8 +1599,7 @@ class RegisterFunctionTest(LandscapeIsolatedTest):
         remote_broker_factory = self.mocker.replace(
             "landscape.broker.remote.RemoteBroker", passthrough=False)
         print_text_mock = self.mocker.replace(print_text)
-        install_mock = self.mocker.replace("twisted.internet."
-                                           "glib2reactor.install")
+        install_mock = self.mocker.replace("landscape.reactor.install")
         time_mock = self.mocker.replace("time")
 
         install_mock()
@@ -1642,8 +1637,7 @@ class RegisterFunctionNoServiceTest(LandscapeIsolatedTest):
         """
         print_text_mock = self.mocker.replace(print_text)
         reactor_mock = self.mocker.proxy("twisted.internet.reactor")
-        install_mock = self.mocker.replace("twisted.internet."
-                                           "glib2reactor.install")
+        install_mock = self.mocker.replace("landscape.reactor.install")
 
         install_mock()
         print_text_mock("Please wait... ", "")
@@ -1678,8 +1672,7 @@ class RegisterFunctionNoServiceTest(LandscapeIsolatedTest):
 
         print_text_mock = self.mocker.replace(print_text)
         reactor_mock = self.mocker.proxy("twisted.internet.reactor")
-        install_mock = self.mocker.replace("twisted.internet."
-                                           "glib2reactor.install")
+        install_mock = self.mocker.replace("landscape.reactor.install")
         # This is unordered. It's just way too much of a pain.
 
         install_mock()
