@@ -447,7 +447,6 @@ class WatchDogService(Service):
 
     def startService(self):
         Service.startService(self)
-
         bootstrap_list.bootstrap(data_path=self._config.data_path,
                                  log_dir=self._config.log_dir)
 
@@ -492,18 +491,21 @@ class WatchDogService(Service):
         return done
 
     def _remove_pid(self):
-        if os.access(self._config.pid_file, os.W_OK):
-            stream = open(self._config.pid_file)
+        pid_file = self._config.pid_file
+        if pid_file is not None and os.access(pid_file, os.W_OK):
+            stream = open(pid_file)
             pid = stream.read()
             stream.close()
             if pid == str(os.getpid()):
-                os.unlink(self._config.pid_file)
+                os.unlink(pid_file)
 
 
 bootstrap_list = BootstrapList([
     BootstrapDirectory("$data_path", "landscape", "root", 0755),
     BootstrapDirectory("$data_path/package", "landscape", "root", 0755),
     BootstrapDirectory("$data_path/package/hash-id", "landscape", "root", 0755),
+    BootstrapDirectory(
+        "$data_path/package/upgrade-tool", "landscape", "root", 0755),
     BootstrapDirectory("$data_path/messages", "landscape", "root", 0755),
     BootstrapDirectory(
         "$data_path/custom-graph-scripts", "landscape", "root", 0755),
